@@ -1,4 +1,3 @@
-;;; -*- mode: Emacs-Lisp; coding: iso-2022-7bit; -*-
 ;;; tramp-cache.el --- file information caching for Tramp
 
 ;; Copyright (C) 2000, 2005, 2006, 2007 by Free Software Foundation, Inc.
@@ -11,8 +10,8 @@
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3 of the License, or
-;; (at your option) any later version.
+;; the Free Software Foundation; either version 3, or (at your option)
+;; any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -142,20 +141,20 @@ Remove also properties of all files in subdirectories."
 (defun tramp-cache-print (table)
   "Prints hash table TABLE."
   (when (hash-table-p table)
-    (let (result tmp)
+    (let (result)
       (maphash
        '(lambda (key value)
-	  (setq tmp (format
-		     "(%s %s)"
-		     (if (processp key)
-			 (prin1-to-string (prin1-to-string key))
-		       (prin1-to-string key))
-		     (if (hash-table-p value)
-			 (tramp-cache-print value)
-		       (if (bufferp value)
-			   (prin1-to-string (prin1-to-string value))
-			 (prin1-to-string value))))
-		result (if result (concat result " " tmp) tmp)))
+	  (let ((tmp (format
+		      "(%s %s)"
+		      (if (processp key)
+			  (prin1-to-string (prin1-to-string key))
+			(prin1-to-string key))
+		      (if (hash-table-p value)
+			  (tramp-cache-print value)
+			(if (bufferp value)
+			    (prin1-to-string (prin1-to-string value))
+			  (prin1-to-string value))))))
+	    (setq result (if result (concat result " " tmp) tmp))))
        table)
       result)))
 
@@ -291,9 +290,9 @@ history."
      tramp-cache-data)
     res))
 
-;; Read persistent connection history.  Applied with
-;; `load-in-progress', because it shall be evaluated only once.
-(when load-in-progress
+;; Read persistent connection history.
+(when (and (stringp tramp-persistency-file-name)
+	   (zerop (hash-table-count tramp-cache-data)))
   (condition-case err
       (with-temp-buffer
 	(insert-file-contents tramp-persistency-file-name)
@@ -308,7 +307,8 @@ history."
      (clrhash tramp-cache-data))
     (error
      ;; File is corrupted.
-     (message "%s" (error-message-string err))
+     (message "Tramp persistency file '%s' is corrupted: %s"
+	      tramp-persistency-file-name (error-message-string err))
      (clrhash tramp-cache-data))))
 
 (provide 'tramp-cache)
