@@ -1,15 +1,15 @@
-;;; -*- coding: iso-2022-7bit; -*-
 ;;; tramp-efs.el --- Make EFS a foreign method in Tramp
+;;; -*- coding: utf-8; -*-
 
 ;; Copyright (C) 2003, 2004, 2007  Free Software Foundation, Inc.
 
-;; Author: Kai Gro,A_(Bjohann <kai.grossjohann@gmx.net>
+;; Author: Kai Grojohann <kai.grossjohann@gmx.net>
 ;; Keywords: comm, processes
 
-;; This file is free software; you can redistribute it and/or modify
+;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3 of the License, or
-;; (at your option) any later version.
+;; the Free Software Foundation; either version 3, or (at your option)
+;; any later version.
 
 ;; This file is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,10 +30,6 @@
 
 (require 'tramp)
 
-;; Avoid byte-compiler warnings.
-(eval-when-compile
-  (byte-compiler-options (warnings (- unused-vars))))
-
 (defvar tramp-efs-method "ftp"
   "Name of the method invoking EFS.")
 
