@@ -1,4 +1,3 @@
-;;; -*- coding: iso-8859-1; -*-
 ;;; tramp-gw.el --- Tramp utility functions for HTTP tunnels and SOCKS gateways
 
 ;; Copyright (C) 2007 Free Software Foundation, Inc.
@@ -10,8 +9,8 @@
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3 of the License, or
-;; (at your option) any later version.
+;; the Free Software Foundation; either version 3, or (at your option)
+;; any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -308,7 +307,7 @@ password in password cache.  This is done for the first try only."
        "%s:%s"
        socks-username
        (tramp-read-passwd
-	proc
+	nil
 	(format
 	 "Password for %s@[%s]: " socks-username (read (current-buffer)))))))))
 
