@@ -1,4 +1,4 @@
-;;; tramp-smb.el --- Tramp access functions for SMB servers -*- coding: iso-8859-1; -*-
+;;; tramp-smb.el --- Tramp access functions for SMB servers
 
 ;; Copyright (C) 2002, 2003, 2004, 2005, 2006,
 ;;   2007 Free Software Foundation, Inc.
@@ -10,8 +10,8 @@
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3 of the License, or
-;; (at your option) any later version.
+;; the Free Software Foundation; either version 3, or (at your option)
+;; any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,15 +30,7 @@
 
 (require 'tramp)
 (require 'tramp-cache)
-
-;; Pacify byte-compiler
-(eval-when-compile (require 'custom))
-
-;; Avoid byte-compiler warnings if the byte-compiler supports this.
-;; Currently, XEmacs supports this.
-(eval-when-compile
-  (when (featurep 'xemacs)
-      (byte-compiler-options (warnings (- unused-vars)))))
+(require 'tramp-compat)
 
 ;; Define SMB method ...
 (defcustom tramp-smb-method "smb"
@@ -79,6 +71,7 @@
    '(;; Connection error / timeout
      "Connection to \\S-+ failed"
      "Read from server failed, maybe it closed the connection"
+     "Call timed out: server did not respond"
      ;; Samba
      "ERRDOS"
      "ERRSRV"
@@ -378,19 +371,19 @@ KEEP-DATE is not handled in case NEWNAME resides on an SMB server."
   "Like `file-local-copy' for Tramp files."
   (with-parsed-tramp-file-name filename nil
     (let ((file (tramp-smb-get-localname localname t))
-	  (tmpfil (tramp-make-temp-file filename)))
+	  (tmpfile (tramp-compat-make-temp-file filename)))
       (unless (file-exists-p filename)
 	(tramp-error
 	 v 'file-error
 	 "Cannot make local copy of non-existing file `%s'" filename))
-      (tramp-message v 4 "Fetching %s to tmp file %s..." filename tmpfil)
-      (if (tramp-smb-send-command v (format "get \"%s\" %s" file tmpfil))
+      (tramp-message v 4 "Fetching %s to tmp file %s..." filename tmpfile)
+      (if (tramp-smb-send-command v (format "get \"%s\" %s" file tmpfile))
 	  (tramp-message
-	   v 4 "Fetching %s to tmp file %s...done" filename tmpfil)
+	   v 4 "Fetching %s to tmp file %s...done" filename tmpfile)
 	(tramp-error
 	 v 'file-error
 	 "Cannot make local copy of file `%s'" filename))
-      tmpfil)))
+      tmpfile)))
 
 ;; This function should return "foo/" for directories and "bar" for
 ;; files.
@@ -582,7 +575,7 @@ Catches errors for shares like \"C$/\", which are common in Microsoft Windows."
     (unless (eq append nil)
       (tramp-error
 	 v 'file-error "Cannot append to file using tramp (`%s')" filename))
-    ;; XEmacs takes a coding system as the seventh argument, not `confirm'
+    ;; XEmacs takes a coding system as the seventh argument, not `confirm'.
     (when (and (not (featurep 'xemacs))
 	       confirm (file-exists-p filename))
       (unless (y-or-n-p (format "File %s exists; overwrite anyway? "
@@ -594,25 +587,23 @@ Catches errors for shares like \"C$/\", which are common in Microsoft Windows."
     (tramp-flush-file-property v localname)
     (let ((file (tramp-smb-get-localname localname t))
 	  (curbuf (current-buffer))
-	  tmpfil)
-      ;; Write region into a tmp file.
-      (setq tmpfil (tramp-make-temp-file filename))
+	  (tmpfile (tramp-compat-make-temp-file filename)))
       ;; We say `no-message' here because we don't want the visited file
       ;; modtime data to be clobbered from the temp file.  We call
       ;; `set-visited-file-modtime' ourselves later on.
       (tramp-run-real-handler
        'write-region
        (if confirm ; don't pass this arg unless defined for backward compat.
-	   (list start end tmpfil append 'no-message lockname confirm)
-	 (list start end tmpfil append 'no-message lockname)))
+	   (list start end tmpfile append 'no-message lockname confirm)
+	 (list start end tmpfile append 'no-message lockname)))
 
-      (tramp-message v 5 "Writing tmp file %s to file %s..." tmpfil filename)
-      (if (tramp-smb-send-command v (format "put %s \"%s\"" tmpfil file))
+      (tramp-message v 5 "Writing tmp file %s to file %s..." tmpfile filename)
+      (if (tramp-smb-send-command v (format "put %s \"%s\"" tmpfile file))
 	  (tramp-message
-	   v 5 "Writing tmp file %s to file %s...done" tmpfil filename)
+	   v 5 "Writing tmp file %s to file %s...done" tmpfile filename)
 	(tramp-error v 'file-error "Cannot write `%s'" filename))
 
-      (delete-file tmpfil)
+      (delete-file tmpfile)
       (unless (equal curbuf (current-buffer))
 	(tramp-error
 	 v 'file-error
@@ -762,7 +753,7 @@ If SHARE is result, entries are of type dir. Otherwise, shares are listed.
 Result is the list (LOCALNAME MODE SIZE MTIME)."
 ;; We are called from `tramp-smb-get-file-entries', which sets the
 ;; current buffer.
-  (let ((line (buffer-substring (point) (tramp-line-end-position)))
+  (let ((line (buffer-substring (point) (tramp-compat-line-end-position)))
 	localname mode size month day hour min sec year mtime)
 
     (if (not share)
@@ -890,7 +881,7 @@ connection if a previous connection has died for some reason."
 	(when (and p (processp p)) (delete-process p))
 
 	(unless (let ((default-directory
-			(tramp-temporary-file-directory)))
+			(tramp-compat-temporary-file-directory)))
 		  (executable-find tramp-smb-program))
 	  (error "Cannot find command %s in %s" tramp-smb-program exec-path))
 
@@ -929,7 +920,8 @@ connection if a previous connection has died for some reason."
 
 	  (let* ((coding-system-for-read nil)
 		 (process-connection-type tramp-process-connection-type)
-		 (p (let ((default-directory (tramp-temporary-file-directory)))
+		 (p (let ((default-directory
+			    (tramp-compat-temporary-file-directory)))
 		      (apply #'start-process
 			     (tramp-buffer-name vec) (tramp-get-buffer vec)
 			     tramp-smb-program args))))
