@@ -1,17 +1,17 @@
-;;; -*- coding: iso-2022-7bit; -*-
 ;;; tramp-util.el --- Misc utility functions to use with Tramp
+;;; -*- coding: utf-8; -*-
 
 ;; Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006,
 ;;   2007 Free Software Foundation, Inc.
 
-;; Author: Kai Gro,A_(Bjohann <kai.grossjohann@gmx.net>
+;; Author: Kai Grojohann <kai.grossjohann@gmx.net>
 ;;         Michael Albinus <michael.albinus@gmx.de>
 ;; Keywords: comm, extensions, processes
 
-;; This file is free software; you can redistribute it and/or modify
+;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3 of the License, or
-;; (at your option) any later version.
+;; the Free Software Foundation; either version 3, or (at your option)
+;; any later version.
 
 ;; This file is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,47 +30,7 @@
 ;;; Code:
 
 (require 'tramp)
-
-;; Define a Tramp minor mode. It's intention is to redefine some keys
-;; for Tramp specific functions, like compilation.
-
-(defvar tramp-minor-mode-map (make-sparse-keymap)
-  "Keymap for Tramp minor mode.")
-
-(define-minor-mode tramp-minor-mode "Tramp minor mode for utility functions."
-  :group 'tramp
-  :global nil
-  :init-value nil
-  :lighter " Tramp"
-  :keymap tramp-minor-mode-map
-  (setq tramp-minor-mode
-	(and tramp-minor-mode (tramp-tramp-file-p default-directory))))
-
-(add-hook 'find-file-hooks 'tramp-minor-mode t)
-(add-hook 'tramp-util-unload-hook
-	  '(lambda ()
-	     (remove-hook 'find-file-hooks 'tramp-minor-mode)))
-
-(add-hook 'dired-mode-hook 'tramp-minor-mode t)
-(add-hook 'tramp-util-unload-hook
-	  '(lambda ()
-	     (remove-hook 'dired-mode-hook 'tramp-minor-mode)))
-
-(defun tramp-remap-command (old-command new-command)
-  "Replaces bindings of OLD-COMMAND by NEW-COMMAND.
-If remapping functionality for keymaps is defined, this happens for all
-bindings.  Otherwise, only bindings active during invocation are taken
-into account.  XEmacs menubar bindings are not changed by this."
-  (if (functionp 'command-remapping)
-      ;; Emacs 22
-      (eval
-       `(define-key tramp-minor-mode-map [remap ,old-command] new-command))
-    ;; previous Emacs versions.
-    (mapcar
-     '(lambda (x)
-	(define-key tramp-minor-mode-map x new-command))
-     (where-is-internal old-command))))
-
+(require 'tramp-compat)
 
 ;; Utility functions.
 
@@ -101,7 +61,9 @@ into account.  XEmacs menubar bindings are not changed by this."
 
 ;; Other open problems are `setenv'/`getenv'.
 
-(unless (fboundp 'start-file-process)
+;; If `start-file-process' isn't defined, it gets an alias in tramp-compat.el.
+(when (eq (symbol-function 'start-file-process)
+	  (symbol-function 'tramp-handle-start-file-process))
   (defadvice executable-find
     (around tramp-advice-executable-find activate)
     "Invoke `tramp-handle-executable-find' for Tramp files."
@@ -129,8 +91,7 @@ into account.  XEmacs menubar bindings are not changed by this."
     "Invoke `tramp-handle-start-process' for Tramp files."
     (if (eq (tramp-find-foreign-file-name-handler default-directory)
 	    'tramp-sh-file-name-handler)
-	(setq ad-return-value
-	      (apply 'tramp-handle-start-file-process (ad-get-args 0)))
+	(setq ad-return-value (apply 'start-file-process (ad-get-args 0)))
       ad-do-it))
   (add-hook 'tramp-util-unload-hook
 	    '(lambda () (ad-unadvise 'start-process)))
@@ -150,16 +111,13 @@ into account.  XEmacs menubar bindings are not changed by this."
 	    '(lambda () (ad-unadvise 'start-process-shell-command)))
 
   (defadvice call-process
-    (around tramp-advice-call-process activate)
-    "Invoke `tramp-handle-call-process' for Tramp files."
-    (let ((fnh (tramp-find-foreign-file-name-handler default-directory)))
-      (cond ((eq fnh 'tramp-sh-file-name-handler)
-	     (setq ad-return-value
-		   (apply 'tramp-handle-call-process (ad-get-args 0))))
-	    ((eq fnh 'tramp-fish-file-name-handler)
-	     (setq ad-return-value
-		   (apply 'tramp-fish-handle-call-process (ad-get-args 0))))
-	    (t ad-do-it))))
+    (around tramp-advice-process-file activate)
+    "Invoke `tramp-handle-process-file' for Tramp files."
+    (if (memq (tramp-find-foreign-file-name-handler default-directory)
+	      '(tramp-sh-file-name-handler
+		tramp-fish-file-name-handler))
+	(setq ad-return-value (apply 'process-file (ad-get-args 0)))
+      ad-do-it))
   (add-hook 'tramp-util-unload-hook
 	    '(lambda () (ad-unadvise 'call-process)))
 
@@ -177,7 +135,7 @@ into account.  XEmacs menubar bindings are not changed by this."
 
   (defadvice call-process-shell-command
     (around tramp-advice-call-process-shell-command activate)
-    "Invoke `tramp-handle-call-process-shell-command' for Tramp files."
+    "Configure `call-process-shell-command' for Tramp files."
     (if (eq (tramp-find-foreign-file-name-handler default-directory)
 	    'tramp-sh-file-name-handler)
 	(with-parsed-tramp-file-name default-directory nil
@@ -189,25 +147,18 @@ into account.  XEmacs menubar bindings are not changed by this."
   (add-hook 'tramp-util-unload-hook
 	    '(lambda () (ad-unadvise 'call-process-shell-command))))
 
-(if (not (fboundp 'file-remote-p))
-    ;; Emacs 21
-    (defalias 'file-remote-p (symbol-function 'tramp-handle-file-remote-p))
-  (unless (tramp-exists-file-name-handler 'file-remote-p "/")
-    ;; XEmacs 21
-    (defadvice file-remote-p
-      (around tramp-advice-file-remote-p
-	      (filename &optional identification connected) activate)
-      "Invoke `tramp-handle-file-remote-p' for Tramp files."
-      (if (eq (tramp-find-foreign-file-name-handler (expand-file-name filename))
-	      'tramp-sh-file-name-handler)
-	  (setq ad-return-value
-		(tramp-handle-file-remote-p filename identification connected))
-	ad-do-it))
-    (add-hook 'tramp-util-unload-hook
-	      '(lambda () (ad-unadvise 'file-remote-p)))))
-
-(if (not (fboundp 'set-file-times))
-    (defalias 'set-file-times (symbol-function 'tramp-handle-set-file-times)))
+(unless (tramp-exists-file-name-handler 'file-remote-p "/")
+  (defadvice file-remote-p
+    (around tramp-advice-file-remote-p
+	    (filename &optional identification connected) activate)
+    "Invoke `tramp-handle-file-remote-p' for Tramp files."
+    (if (eq (tramp-find-foreign-file-name-handler (expand-file-name filename))
+	    'tramp-sh-file-name-handler)
+	(setq ad-return-value
+	      (tramp-handle-file-remote-p filename identification connected))
+      ad-do-it))
+  (add-hook 'tramp-util-unload-hook
+	    '(lambda () (ad-unadvise 'file-remote-p))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -250,7 +201,7 @@ into account.  XEmacs menubar bindings are not changed by this."
 ;; values might be different for remote hosts, we set the variables to
 ;; the "Not Set" (default) value.
 
-(mapcar
+(mapc
  '(lambda (x)
 
     (eval
@@ -363,7 +314,7 @@ If it is an absolute file name, and not a remote one, prepend the remote part."
     ;; Emacs 22 uses `gud-file-name' which we should do as well.
     ;; `gud-<MINOR-MODE>-directories' must be Tramp file names.
     (if (functionp 'gud-file-name)
-	(funcall 'gud-file-name filename)
+	(funcall (symbol-function 'gud-file-name) filename)
       filename)))
 
 (defun tramp-gud-massage-args (args)
@@ -384,9 +335,10 @@ Works only for relative file names and Tramp file names."
   args)
 
 (when (functionp 'gud-find-file)
-  (set 'gud-find-file 'tramp-gud-file-name))
+  (defvar gud-find-file)
+  (setq gud-find-file 'tramp-gud-file-name))
 
-(mapcar
+(mapc
  '(lambda (x)
 
     ;; (X)Emacs 21 use `gud-<MINOR-MODE>-find-file'.
@@ -451,7 +403,7 @@ Works only for relative file names and Tramp file names."
 
 ;; Several packages expect that the processes run locally.
 
-(mapcar
+(mapc
  '(lambda (x)
     (eval
      `(defadvice ,x
